ListManagerApiEnv enum
The API environment for the List Manager (event collection) service.
Values
- prod → const ListManagerApiEnv
-
The production API environment.
const ListManagerApiEnv('https://ec.adadapted.com') - dev → const ListManagerApiEnv
-
The development (sandbox) API environment.
const ListManagerApiEnv('https://sandec.adadapted.com') - mock → const ListManagerApiEnv
-
Used only for unit testing/mock data.
const ListManagerApiEnv('MOCK_DATA')
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- index → int
-
A numeric identifier for the enumerated value.
no setterinherited
- name → String
-
Available on Enum, provided by the EnumName extension
The name of the enum value.no setter - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- url → String
-
The base URL requests are made against.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
-
values
→ const List<
ListManagerApiEnv> - A constant List of the values in this enum, in order of their declaration.